@@ -14,7 +14,7 @@
 
 from __future__ import print_function, absolute_import
 
-if __name__=='pymol.importing':
+if True:
     
     import re
     import os
@@ -23,11 +23,9 @@ if __name__=='pymol.importing':
     import traceback
     import pymol
     cmd = sys.modules["pymol.cmd"]
-    from . import setting
     from . import selector
     from . import colorprinting
-    from .cmd import _cmd,lock,unlock,Shortcut, \
-          _feedback,fb_module,fb_mask, \
+    from .cmd import _cmd, \
           DEFAULT_ERROR, DEFAULT_SUCCESS, _raising, is_ok, is_error, \
           _load, is_list, space_sc, safe_list_eval, is_string, loadable
     from .constants import _loadable
@@ -37,11 +35,8 @@ if __name__=='pymol.importing':
         raise pymol.IncentiveOnlyException(
                 "'%s' format not supported by this PyMOL build" % format)
 
-    from chempy import io,PseudoFile
+    from chempy import io
     
-    # TODO remove (keep for now for eventual legacy uses in scripts)
-    loadable_sc = Shortcut(loadable.__dict__.keys()) 
-
     def filename_to_objectname(fname, _self=cmd):
         oname, _, _, _ = filename_to_format(fname)
         return _self.get_legal_name(oname)
@@ -484,7 +479,7 @@ SEE ALSO
             raw_seq = seq_dict[key].replace('-','')
             _self.fab(raw_seq, key, quiet=quiet)
 
-    def _processFASTA(fname,quiet=1,_self=cmd):
+    def _processFASTA(fname, oname, quiet=1, _self=cmd):
         legal_dict = {}
         seq_dict = {}
         seq_order = []
@@ -500,6 +495,13 @@ SEE ALSO
                     key = legal_key
                 elif key:
                     seq = line
+
+                    if '-' in seq:
+                        # sequence alignment
+                        from pymol.seqalign import load_aln_multi
+                        return load_aln_multi(fname, oname, quiet=quiet,
+                                _self=_self)
+
                     seq_dict[key] = seq_dict.get(key,'') + seq
         for key in seq_order:
             raw_seq = seq_dict[key].replace('-','')
@@ -1323,7 +1325,7 @@ PYMOL API
         return r
     
     def fetch(code, name='', state=0, finish=1, discrete=-1,
-              multiplex=-2, zoom=-1, type='', async_=-1, path='',
+              multiplex=-2, zoom=-1, type='', async_=0, path='',
               file=None, quiet=1, _self=cmd, **kwargs):
         
         '''
@@ -1348,6 +1350,9 @@ ARGUMENTS
     type = str: cif, pdb, pdb1, 2fofc, fofc, emd, cid, sid {default: cif
     (default was "pdb" up to 1.7.6)}
 
+    async_ = 0/1: download in the background and do not block the PyMOL
+    command line {default: 0 -- changed in PyMOL 2.3}
+
 PYMOL API
 
     cmd.fetch(string code, string name, int state, init finish,
@@ -1617,7 +1622,7 @@ DESCRIPTION
         'py': lambda filename, _self: _self.do("_ run %s" % filename),
         'pml': lambda filename, _self: _self.do("_ @%s" % filename),
         'pwg': _processPWG,
-        'aln': _processALN,
+        'aln': 'pymol.seqalign:load_aln_multi',
         'fasta': _processFASTA,
         'png': 'pymol.viewing:load_png',
         'idx': load_idx,
